@@ -26,9 +26,12 @@
 Q_QMLTYPE_EXPORT void qml_register_types_org_deepin_ds_notificationcenter()
 {
     QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
+    QMetaType::fromType<QAbstractItemModel *>().id();
+    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
+    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
+    QMetaType::fromType<QAbstractListModel *>().id();
     qmlRegisterTypesAndRevisions<notifycenter::NotifyAccessor>("org.deepin.ds.notificationcenter", 1);
     qmlRegisterTypesAndRevisions<notifycenter::NotifyModel>("org.deepin.ds.notificationcenter", 1);
-    qmlRegisterAnonymousType<QAbstractItemModel, 254>("org.deepin.ds.notificationcenter", 1);
     qmlRegisterTypesAndRevisions<notifycenter::NotifyStagingModel>("org.deepin.ds.notificationcenter", 1);
     QT_WARNING_POP
     qmlRegisterModule("org.deepin.ds.notificationcenter", 1, 0);
